clear
set scheme sj
cap cd "PUT YOUR DIRECTORY HERE"
set more off


****************
*** ANALYSIS ***
****************
use data, clear

// Sample selection
drop if exclude==1	// drops 4 subjs as described in comments
drop exclude

// Sample Size
tab FR group	

//create table for summary stats / comparison of groups
foreach i of varlist ///
age male percent_may21 heardmay21 percent_rapture_lifetime timespent_hours percent_saved oct21_belief   {
	reg `i' FRx6 FRx50 SDAx6 SDAx50, vce(robust) noc
	test FRx50 = FRx6
	loc p1 `r(p)'
	if `p1'==. loc p1 =999	// placeholder so outreg doesn't mess up
	test SDAx50 = SDAx6
	loc p2 `r(p)'
	if `p2'==. loc p2 =999

	reg `i' FR, vce(robust) 
}


//create cutoff table
bys SDA: sum cutoff, detail
sum cutoff if FRx6==1, detail
sum cutoff if FRx50==1, detail
sum cutoff if SDAx6==1, detail
sum cutoff if SDAx50==1, detail

//p-values / Standard Errors
reg cutoff FR SDA, vce(robust) noc
test FR = SDA
reg cutoff FRx6 FRx50 SDAx6 SDAx50, vce(robust) noc
test FRx50 = FRx6
test SDAx50 = SDAx6

//Medians -> SE
set seed 1
bootstrap r(p50), nodots reps(100000): summarize cutoff if SDA==1, detail
bootstrap r(p50), nodots reps(100000): summarize cutoff if SDAx6==1, detail
bootstrap r(p50), nodots reps(100000): summarize cutoff if SDAx50==1, detail









use data, clear

// Sample selection
drop if exclude==1	// drops 4 subjs as described in comments
drop exclude

//Medians -> p-value: Takes a while to do all the bootstrapping
preserve
clear
local obs=100000
set obs `obs'
gen diff=0
save "mediandata", replace
restore

preserve
keep SDA* cutoff
keep if SDA==1
gen random=0
gen SDAx50_=0
save t, replace

forvalues i = 1/`obs' {
	qui use t, clear	
	disp `i'
	qui replace random = uniform() if SDA!=.
	qui sort random
	qui replace SDAx50_=0
	qui replace SDAx50_=1 if _n>13 & _n<30
	qui sum cutoff if SDAx50_==1, detail
	local median1=r(p50)
	qui sum cutoff if SDAx50_==0, detail
	local median2=r(p50)
	local diff=`median1'-`median2'
	qui use "mediandata", clear
	qui replace diff=`diff' if _n==`i'
	qui save "mediandata", replace
}

restore

use "mediandata", clear
gen absdiff=abs(diff)
sort absdiff
gen equal_or_higher=(absdiff>5)
// this is the statistic!
sum equal_or_higher






use data, clear

// Sample selection
drop if exclude==1	// drops 4 subjs as described in comments
drop exclude

***********************************
**Plots - distribution of beliefs / cutoffs then combine
************************************

****Beliefs
twoway(hist percent_may21 if FR==1, width(2) freq color(black)) ///
	(hist percent_may21 if FR==0, color(gs11)  width(2) freq), ///
	xtitle("Percent belief that May 21st will be Judgement Day") ///
	legend(off) ///
	title("{bf:Panel A: Distribution of beliefs in Harold Camping's prophecy}") 
graph save "./output/fig_may21_belief.gph", replace


****Cutoffs
//better for way graph looks for some reason
replace cutoff=501 if cutoff==500
twoway(hist cutoff if FR==1, width(10) freq color(black)) ///
	(hist cutoff if FR==0, width(10) freq color(gs11)) if group==0, ///
	xlabel(5 50 (50) 500 ">500") ylabel(0 (5) 15) ///
	xtitle("") ///
	legend(off) title("{bf:Panel B: Distribution of Cutoff Values}") subtitle("6% Treatment", box bexpand)
graph save "./output/fig_cutoff_histogram1.gph", replace

twoway(hist cutoff if FR==1, width(10) freq color(black)) ///
	(hist cutoff if FR==0, width(10) freq color(gs11)) if group==1, ///
	xlabel(5 50 (50) 500 ">500") ylabel(0 (5) 15) ///
	xtitle("Maximum amount of money (cutoff) willing to forego in 4 weeks for $5 today") ///
	legend(order(1 "Family Radio" 2 "Seventh Day Adventists") size(2) symysize(2)  symxsize(2) ) ///
   subtitle("50% Treatment" , box bexpand)
graph save "./output/fig_cutoff_histogram2_legend.gph", replace


cap net install grc1leg
grc1leg "./output/fig_may21_belief.gph" "./output/fig_cutoff_histogram1.gph" ///
 "./output/fig_cutoff_histogram2_legend.gph", legendfrom("./output/fig_cutoff_histogram2_legend.gph") ///
 cols(1) altshrink  iscale(2)  ysize(4) xsize(4)
graph save "./output/figure_histogram_combined.gph", replace

********Need to change x scale and y scale to 10 and 10: no idea why can't do this with command above
graph use "./output/figure_histogram_combined.gph"
graph export "./output/figure_histogram_combined.png", replace width(2000)


